@@ -1,15 +1,11 @@
 import os, boto3, subprocess, uuid, json, datetime, sys
-SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
-sys.path.append(os.path.join(SCRIPT_DIR))
-
 from dateutil.tz import *
+SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
+
+sys.path.append(SCRIPT_DIR)
 import quick_utils
 
-SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
 HOME_PATH = os.path.expanduser('~')
-AWS_CONFIG = quick_utils.loadJSON(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
-             if os.path.exists(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
-             else quick_utils.loadJSON(os.path.join(SCRIPT_DIR,'aws_config_constants.json'))
 
 # initialize S3 access
 if os.environ.get('AWS_ACCESS_KEY_ID') not in [None, ''] and os.environ.get('AWS_SECRET_ACCESS_KEY') not in [None, ''] and os.environ.get('HOME') not in [None, '']:
@@ -428,6 +424,10 @@ def get_objects_s3( args ):
     ---
     response: AWS-formatted response containing full metadata for each object
     """
+    AWS_CONFIG = quick_utils.loadJSON(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
+                 if os.path.exists(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
+                 else quick_utils.loadJSON(os.path.join(SCRIPT_DIR,'aws_config_constants.json'))
+
     s3path = args['path']
 
     bucket = s3path.split('/')[2]
@@ -821,6 +821,10 @@ def list_objects( s3path, searchpattern = '' ):
         },...
     ]}
     """
+    AWS_CONFIG = quick_utils.loadJSON(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
+                 if os.path.exists(os.path.join(HOME_PATH,'.bioshedinit/','aws_config_constants.json')) \
+                 else quick_utils.loadJSON(os.path.join(SCRIPT_DIR,'aws_config_constants.json'))
+
     bucket = s3path.split('/')[2]
     key = str('/'.join(s3path.split('/')[3:])).rstrip('/') + '/'
     region = AWS_CONFIG['aws_region']
