@@ -213,8 +213,9 @@ def bioshed_setup_aws( args ):
             )
             f.write('  public_key = "{}"\n'.format(PKEY_INPUT))
             f.write('}\n\n')
-    with open(AWS_CONFIG_FILE,'w') as f:
-        json.dump(AWS_CONSTANTS_JSON, f)
+    quick_utils.add_to_json( AWS_CONFIG_FILE, AWS_CONSTANTS_JSON)
+    # with open(AWS_CONFIG_FILE,'w') as f:
+    #     json.dump(AWS_CONSTANTS_JSON, f)
     os.chdir(INIT_PATH)
     # initialize terraform
     subprocess.call('terraform init', shell=True)
